@@ -3,14 +3,8 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <bownie@bownie.com>
-
-    The moral right of the authors to claim authorship of this work
-    has been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
+    See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -27,6 +21,7 @@
 
 #include "Device.h"
 #include "Instrument.h"
+#include "MidiMetronome.h"
 #include "MidiProgram.h"
 #include "ControlParameter.h"
 #include "Controllable.h"
@@ -72,7 +67,6 @@ public:
     // Instrument must be on heap; I take ownership of it
     virtual void addInstrument(Instrument*);
 
-    void removeMetronome();
     void setMetronome(const MidiMetronome &);
     const MidiMetronome* getMetronome() const { return m_metronome; }
 
