@@ -2,14 +2,8 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-
-    This program is Copyright 2000-2007
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <bownie@bownie.com>
-
-    The moral right of the authors to claim authorship of this work
-    has been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
+    See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -168,8 +162,7 @@ SimpleRulerScale::SimpleRulerScale(Composition *composition,
 				   double origin, double ratio) :
     RulerScale(composition),
     m_origin(origin),
-    m_ratio(ratio),
-    m_firstBar(0)
+    m_ratio(ratio)
 {
     // nothing
 }
@@ -177,8 +170,7 @@ SimpleRulerScale::SimpleRulerScale(Composition *composition,
 SimpleRulerScale::SimpleRulerScale(const SimpleRulerScale &ruler):
     RulerScale(ruler.getComposition()),
     m_origin(ruler.getOrigin()),
-    m_ratio(ruler.getUnitsPerPixel()),
-    m_firstBar(ruler.getFirstVisibleBar())
+    m_ratio(ruler.getUnitsPerPixel())
 {
     // nothing
 }
