@@ -2,14 +2,8 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-
-    This program is Copyright 2000-2007
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <bownie@bownie.com>
-
-    The moral right of the authors to claim authorship of this work
-    has been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
+    See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -145,9 +139,6 @@ public:
     double getUnitsPerPixel() const { return m_ratio; }
     void   setUnitsPerPixel(double ratio) { m_ratio = ratio; }
 
-    virtual int getFirstVisibleBar() const { return m_firstBar; }
-    void setFirstVisibleBar(int fb) { m_firstBar = fb; }
-
     virtual double getBarPosition(int n) const;
     virtual double getBarWidth(int n) const;
     virtual double getBeatWidth(int n) const;
@@ -158,7 +149,6 @@ public:
 protected:
     double m_origin;
     double m_ratio;
-    int m_firstBar;
 
 private:
     SimpleRulerScale(const SimpleRulerScale &ruler);
