@@ -4,14 +4,8 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-
-    This program is Copyright 2000-2007
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <bownie@bownie.com>
-
-    The moral right of the authors to claim authorship of this work
-    has been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
+    See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -382,7 +376,7 @@ public:
     /**
      * Give all events between the start of the timeslice containing
      * from and the start of the timeslice containing to the same new
-     * group id and the given type
+     * group id and the given type.
      *
      * Do not use this for making tuplet groups, unless the events
      * in the group already have the other tuplet properties or you
@@ -390,6 +384,20 @@ public:
      */
     void makeBeamedGroup(iterator from, iterator to, std::string type);
 
+    /**
+     * Give all events between from and to the same new group id and
+     * the given type.
+     *
+     * Use makeBeamedGroup for normal notes.  This function is usually
+     * used for groups of grace notes, which are equal in time and
+     * distinguished by subordering.
+     *
+     * Do not use this for making tuplet groups, unless the events
+     * in the group already have the other tuplet properties or you
+     * intend to add those yourself.
+     */
+    void makeBeamedGroupExact(iterator from, iterator to, std::string type);
+
 
     /**
      * Make a beamed group of tuplet type, whose tuplet properties are
@@ -543,7 +551,8 @@ protected:
     void setInsertedNoteGroup(Event *e, iterator i);
 
     /// for use by makeBeamedGroup
-    void makeBeamedGroupAux(iterator from, iterator to, std::string type);
+    void makeBeamedGroupAux(iterator from, iterator to, std::string type,
+			    bool groupGraces);
 
     /// for use by unbeam
     void unbeamAux(iterator from, iterator to);
