@@ -3,14 +3,8 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <bownie@bownie.com>
-
-    The moral right of the authors to claim authorship of this work
-    has been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
+    See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -24,6 +18,7 @@
 #include "Studio.h"
 #include "MidiDevice.h"
 #include "AudioDevice.h"
+#include "SoftSynthDevice.h"
 #include "Instrument.h"
 
 #include "Segment.h"
@@ -365,18 +360,23 @@ const MidiMetronome*
 Studio::getMetronomeFromDevice(DeviceId id)
 {
     std::vector<Device*>::iterator it;
-    MidiDevice *midiDevice;
 
-    for (it = m_devices.begin(); it != m_devices.end(); it++)
-    {
-        midiDevice = dynamic_cast<MidiDevice*>(*it);
+    for (it = m_devices.begin(); it != m_devices.end(); it++) {
+
+        MidiDevice *midiDevice = dynamic_cast<MidiDevice*>(*it);
 
         if (midiDevice && 
             midiDevice->getId() == id &&
-            midiDevice->getMetronome())
-        {
+            midiDevice->getMetronome()) {
             return midiDevice->getMetronome();
         }
+
+	SoftSynthDevice *ssDevice = dynamic_cast<SoftSynthDevice *>(*it);
+        if (ssDevice && 
+            ssDevice->getId() == id &&
+            ssDevice->getMetronome()) {
+            return ssDevice->getMetronome();
+        }
     }
 
     return 0;
