@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
- 
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -105,7 +98,12 @@ PasteToTriggerSegmentCommand::execute()
             }
         }
 
-        m_segment->setLabel(qstrtostr(m_label));
+        if (m_label == "" && m_clipboard->isSingleSegment()) {
+            m_segment->setLabel(m_clipboard->getSingleSegment()->getLabel());
+        }
+        else {
+            m_segment->setLabel(qstrtostr(m_label));
+        }
 
         TriggerSegmentRec *rec =
             m_composition->addTriggerSegment(m_segment, m_basePitch, m_baseVelocity);
