@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
- 
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -110,7 +103,7 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
 
         QString text("%1 %");
         if (*i == 100)
-            text = "%1 % (normal)";
+            text = i18n("%1 % (normal)");
         m_spacing->insertItem(text.arg(*i));
 
         if (*i == defaultSpacing) {
@@ -134,7 +127,7 @@ NotationConfigurationPage::NotationConfigurationPage(KConfig *cfg,
 
         QString text = QString("%1 %").arg(*i);
         if (*i == 40)
-            text = "40 % (normal)";
+            text = i18n("%1 % (normal)").arg(*i);
         else if (*i == 0)
             text = i18n("None");
         else if (*i == 100)
