@@ -4,14 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
-
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -56,6 +49,7 @@ public:
 protected slots:
     void slotVerseNumberChanged(int);
     void slotAddVerse();
+    void slotRemoveVerse();
 
 protected:
     Segment *m_segment;
@@ -64,6 +58,7 @@ protected:
     QComboBox *m_verseNumber;
     QTextEdit *m_textEdit;
     QPushButton *m_verseAddButton;
+    QPushButton *m_verseRemoveButton;
 
     int m_verseCount;
     std::vector<QString> m_texts;
@@ -71,6 +66,7 @@ protected:
 
     void countVerses();
     void unparse();
+    void verseDialogRepopulate();
 };
 
 }
