@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
- 
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -274,6 +267,8 @@ NotationStrings::makeNoteMenuLabel(timeT duration,
             return QString("1/%1").arg(wholeNote / duration);
         } else if ((duration / wholeNote) * wholeNote == duration) {
             return QString("%1/1").arg(duration / wholeNote);
+        } else if ((wholeNote /(duration*2/3)) * (duration*2/3) == wholeNote) {
+            return QString("3/%1").arg(wholeNote / (duration*1/3));
         } else {
             return i18n("%1 ticks").arg(duration);
             plural = false;
