@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
-
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -256,6 +249,11 @@ public:
                                 bool preview = false,
                                 bool redrawNow = false);
 
+    /**
+     * Get the average velocity of the selected notes
+     */
+    int getVelocityFromSelection();
+
     /**
      * Show and sound the given note.  The height is used for display,
      * the pitch for performance, so the two need not correspond (e.g.
@@ -619,6 +617,10 @@ public slots:
     void slotFinePositionDown();
     void slotFinePositionRestore();
 
+    void slotVelocityUp();
+    void slotVelocityDown();
+    void slotSetVelocities();
+
     void slotMakeVisible();
     void slotMakeInvisible();
 
