@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
- 
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -125,6 +118,9 @@ NoteInserter::NoteInserter(NotationView* view)
 
     connect(m_parentView, SIGNAL(changeAccidental(Accidental, bool)),
             this, SLOT(slotSetAccidental(Accidental, bool)));
+
+    // Push down the default RadioAction on Accidentals.
+    m_parentView->actionCollection()->action("no_accidental")->activate();
 }
 
 NoteInserter::NoteInserter(const QString& menuName, NotationView* view)
@@ -139,6 +135,9 @@ NoteInserter::NoteInserter(const QString& menuName, NotationView* view)
 {
     connect(m_parentView, SIGNAL(changeAccidental(Accidental, bool)),
             this, SLOT(slotSetAccidental(Accidental, bool)));
+
+    // Push down the default RadioAction on Accidentals.
+    m_parentView->actionCollection()->action("no_accidental")->activate();
 }
 
 NoteInserter::~NoteInserter()
@@ -604,12 +603,13 @@ void NoteInserter::slotSetNote(Note::Type nt)
 
 void NoteInserter::slotSetDots(unsigned int dots)
 {
-    m_noteDots = dots;
-
     KToggleAction *dotsAction = dynamic_cast<KToggleAction *>
                                 (actionCollection()->action("toggle_dot"));
-    if (dotsAction)
+    if (dotsAction && m_noteDots != dots) {
         dotsAction->setChecked(dots > 0);
+        slotToggleDot();
+        m_noteDots = dots;
+    }
 }
 
 void NoteInserter::slotSetAccidental(Accidental accidental,
