@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
- 
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -122,6 +115,17 @@ RestInserter::doAddCommand(Segment &segment, timeT time, timeT endTime,
     return insertionCommand->getLastInsertedEvent();
 }
 
+void RestInserter::slotSetDots(unsigned int dots)
+{
+    KToggleAction *dotsAction = dynamic_cast<KToggleAction *>
+                                (actionCollection()->action("toggle_dot"));
+    if (dotsAction && m_noteDots != dots) {
+        dotsAction->setChecked(dots > 0);
+        slotToggleDot();
+        m_noteDots = dots;
+    }
+}
+
 void RestInserter::slotToggleDot()
 {
     m_noteDots = (m_noteDots) ? 0 : 1;
@@ -140,7 +144,7 @@ void RestInserter::slotNotesSelected()
 {
     Note note(m_noteType, m_noteDots);
     QString actionName(NotationStrings::getReferenceName(note));
-    actionName.replace(QRegExp(" "), "_");
+    actionName.replace(QRegExp("-"), "_");
     m_parentView->actionCollection()->action(actionName)->activate();
 }
 
