@@ -3,14 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
- 
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
+    Copyright 2000-2008 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -1202,8 +1195,11 @@ EditView::getPitchFromNoteInsertAction(QString name,
             scalePitch = 0;
         }
 
+	//
+	// Note: middle-C is in octave 5 + octaveBase (default = -2) = 3 (hjj)
+	//
         Pitch pitch
-        (scalePitch, 4 + octave + clef.getOctave(), key, accidental);
+        (scalePitch, 3 + octave + clef.getOctave(), key, accidental);
         return pitch.getPerformancePitch();
 
     } else {
