@@ -3,18 +3,11 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
- 
-    This program is Copyright 2000-2008
-        Guillaume Laurent   <glaurent@telegraph-road.org>,
-        Chris Cannam        <cannam@all-day-breakfast.com>,
-        Richard Bown        <richard.bown@ferventsoftware.com>
+    Copyright 2000-2008 the Rosegarden development team.
 
     This file is Copyright 2006
 	D. Michael McIntyre <dmmcintyr@users.sourceforge.net>
  
-    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
-    Bown to claim authorship of this work have been asserted.
- 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
  
